@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -710,6 +710,14 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] ETC_UTC = new String[] {
+               "koordinert universaltid",
+               "UTC",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Mauritius = new String[] {
                "mauritisk normaltid",
                "",
@@ -1233,16 +1241,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
-            { "UTC",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "UTC", ETC_UTC },
             { "Asia/Aden", Arabian },
             { "timezone.excity.America/Phoenix", "Phoenix" },
             { "timezone.excity.Asia/Katmandu", "Katmandu" },
@@ -1270,6 +1269,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "timezone.excity.Antarctica/Vostok", "Vostok" },
             { "America/Panama", America_Eastern },
             { "timezone.excity.America/North_Dakota/Beulah", "Beulah, Nord-Dakota" },
+            { "JST", Japan },
             { "timezone.excity.Pacific/Fiji", "Fiji" },
             { "timezone.excity.Europe/Gibraltar", "Gibraltar" },
             { "Europe/Jersey", GMT },
@@ -1288,6 +1288,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Tallinn", "Tallinn" },
             { "Asia/Phnom_Penh", Indochina },
             { "Africa/Kigali", Africa_Central },
+            { "BET", Brasilia },
             { "timezone.excity.Pacific/Guam", "Guam" },
             { "timezone.excity.Europe/Vaduz", "Vaduz" },
             { "America/Argentina/Salta", Argentina },
@@ -1425,6 +1426,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "timezone.excity.America/Thule", "Thule" },
             { "timezone.excity.America/Grand_Turk", "Grand Turk" },
             { "America/Yakutat", Alaska },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "Europe/Vienna", Europe_Central },
             { "timezone.excity.America/Winnipeg", "Winnipeg" },
             { "timezone.excity.Antarctica/Macquarie", "Macquarie" },
@@ -1472,6 +1474,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Pacific/Truk", Truk },
             { "timezone.excity.Africa/Conakry", "Conakry" },
             { "timezone.excity.Asia/Jakarta", "Jakarta" },
+            { "SST", Solomon },
             { "America/Jamaica", America_Eastern },
             { "Asia/Bishkek", Kyrgystan },
             { "Atlantic/Stanley", Falkland },
@@ -1492,6 +1495,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "timezone.excity.Indian/Mahe", "Mah\u00e9" },
             { "Europe/San_Marino", Europe_Central },
             { "America/Indiana/Tell_City", America_Central },
+            { "BST", Bangladesh },
             { "timezone.excity.Europe/Isle_of_Man", "Man" },
             { "Pacific/Saipan", Chamorro },
             { "timezone.excity.America/Curacao", "Cura\u00e7ao" },
@@ -1500,6 +1504,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Antarctica/Rothera", Rothera },
             { "timezone.excity.America/Guyana", "Guyana" },
             { "Asia/Damascus", Europe_Eastern },
+            { "MIT", Apia },
             { "America/Argentina/San_Luis", Argentina_Western },
             { "timezone.excity.Europe/Paris", "Paris" },
             { "timezone.excity.Europe/Zagreb", "Zagreb" },
@@ -1517,16 +1522,6 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Chita", "Tsjita" },
             { "America/Indiana/Marengo", America_Eastern },
             { "timezone.excity.America/Rankin_Inlet", "Rankin Inlet" },
-            { "America/Punta_Arenas",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "timezone.excity.America/Santarem", "Santar\u00e9m" },
             { "timezone.excity.Asia/Tomsk", "Tomsk" },
             { "timezone.excity.Europe/Helsinki", "Helsingfors" },
@@ -1611,17 +1606,8 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Europe/Tallinn", Europe_Eastern },
             { "Africa/Johannesburg", Africa_Southern },
             { "timezone.excity.Pacific/Fakaofo", "Fakaofo" },
+            { "EAT", Africa_Eastern },
             { "Africa/Bangui", Africa_Western },
-            { "Europe/Astrakhan",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Juba", Africa_Eastern },
             { "America/Campo_Grande", Amazon },
             { "America/Belem", Brasilia },
@@ -1642,6 +1628,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "America/Whitehorse", America_Pacific },
             { "timezone.excity.America/Cuiaba", "Cuiaba" },
             { "Pacific/Noumea", New_Caledonia },
+            { "ECT", Europe_Central },
             { "timezone.excity.Atlantic/Azores", "Asorane" },
             { "timezone.excity.Australia/Melbourne", "Melbourne" },
             { "America/Montreal", America_Eastern },
@@ -1669,6 +1656,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "timezone.excity.America/Regina", "Regina" },
             { "SystemV/YST9YDT", Alaska },
             { "America/Merida", America_Central },
+            { "CAT", Africa_Central },
             { "America/St_Kitts", Atlantic },
             { "timezone.excity.America/Thunder_Bay", "Thunder Bay" },
             { "America/Fort_Nelson", America_Mountain },
@@ -1678,7 +1666,6 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Africa/Monrovia", GMT },
             { "Asia/Ust-Nera", Vladivostok },
             { "timezone.excity.America/Louisville", "Louisville" },
-            { "timezone.excity.America/Cancun", "Canc\u00fan" },
             { "timezone.excity.Australia/Broken_Hill", "Broken Hill" },
             { "timezone.excity.Europe/Kaliningrad", "Kaliningrad" },
             { "America/North_Dakota/New_Salem", America_Central },
@@ -1692,16 +1679,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Europe/Vatican", Europe_Central },
             { "timezone.excity.America/Asuncion", "Asunci\u00f3n" },
             { "Asia/Amman", Europe_Eastern },
-            { "Etc/UTC",
-                new String[] {
-                    "koordinert universaltid",
-                    "UTC",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "Etc/UTC", ETC_UTC },
             { "timezone.excity.Europe/Chisinau", "Chi\u0219in\u0103u" },
             { "timezone.excity.America/Moncton", "Moncton" },
             { "Asia/Singapore", Singapore },
@@ -1755,6 +1733,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Europe/Isle_of_Man", GMT },
             { "America/Araguaina", Brasilia },
             { "timezone.excity.Pacific/Easter", "P\u00e5ske\u00f8ya" },
+            { "ACT", Australia_Central },
             { "Asia/Novosibirsk", Novosibirsk },
             { "Africa/Tunis", Europe_Central },
             { "Pacific/Fakaofo", Tokelau },
@@ -1781,6 +1760,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Kirov", "Kirov" },
             { "timezone.excity.America/Creston", "Creston" },
             { "timezone.excity.Africa/Cairo", "Kairo" },
+            { "AET", Australia_Eastern },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "timezone.excity.Europe/Warsaw", "Warszawa" },
             { "Europe/Skopje", Europe_Central },
@@ -1790,16 +1770,6 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Africa/Algiers", Europe_Central },
             { "Europe/Mariehamn", Europe_Eastern },
             { "America/Anguilla", Atlantic },
-            { "Europe/Saratov",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Europe/Gibraltar", Europe_Central },
             { "Africa/Conakry", GMT },
             { "America/Havana", Cuba },
@@ -1836,16 +1806,6 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "America/Port_of_Spain", Atlantic },
             { "Asia/Beirut", Europe_Eastern },
             { "timezone.excity.Asia/Baghdad", "Bagdad" },
-            { "Pacific/Bougainville",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Sao_Tome", Africa_Western },
             { "Indian/Chagos", Indian_Ocean },
             { "timezone.excity.America/Metlakatla", "Metlakatla" },
@@ -1857,6 +1817,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "timezone.excity.America/Panama", "Panama" },
             { "timezone.excity.Europe/Simferopol", "Simferopol" },
             { "timezone.excity.Indian/Kerguelen", "Kerguelen" },
+            { "CNT", Newfoundland },
             { "timezone.excity.Europe/Volgograd", "Volgograd" },
             { "timezone.excity.Europe/Monaco", "Monaco" },
             { "Asia/Tashkent", Uzbekistan },
@@ -1878,6 +1839,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "timezone.excity.America/Managua", "Managua" },
             { "America/Kralendijk", Atlantic },
             { "Indian/Christmas", Christmas },
+            { "NET", Armenia },
             { "America/Inuvik", America_Mountain },
             { "America/Iqaluit", America_Eastern },
             { "Pacific/Funafuti", Tuvalu },
@@ -1919,11 +1881,13 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Asia/Chongqing", China },
             { "America/Indiana/Knox", America_Central },
             { "timezone.excity.Asia/Saigon", "Ho Chi Minh-byen" },
+            { "PLT", Pakistan },
             { "America/North_Dakota/Beulah", America_Central },
             { "timezone.excity.Asia/Makassar", "Makassar" },
             { "Pacific/Apia", Apia },
             { "Pacific/Niue", Niue },
             { "timezone.excity.Asia/Yekaterinburg", "Jekaterinburg" },
+            { "CST", America_Central },
             { "timezone.excity.Europe/Sofia", "Sofia" },
             { "MST7MDT", America_Mountain },
             { "America/Monterrey", America_Central },
@@ -1935,6 +1899,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "timezone.excity.America/Denver", "Denver" },
             { "Indian/Mahe", Seychelles },
             { "Asia/Aqtobe", Kazakhstan_Western },
+            { "CTT", China },
             { "timezone.excity.Asia/Gaza", "Gaza" },
             { "timezone.excity.Africa/Ceuta", "Ceuta" },
             { "Africa/Libreville", Africa_Western },
@@ -1944,6 +1909,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "timezone.excity.Antarctica/Troll", "Troll" },
             { "America/Aruba", Atlantic },
             { "America/North_Dakota/Center", America_Central },
+            { "PNT", America_Mountain },
             { "timezone.excity.Asia/Hong_Kong", "Hongkong" },
             { "timezone.excity.America/Port-au-Prince", "Port-au-Prince" },
             { "America/Tijuana", America_Pacific },
@@ -1952,8 +1918,8 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Kwajalein", "Kwajalein" },
             { "SystemV/YST9", Gambier },
             { "Africa/Douala", Africa_Western },
-            { "America/Chihuahua", Mexico_Pacific },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Chihuahua", America_Central },
+            { "America/Ojinaga", America_Central },
             { "Asia/Hovd", Hovd },
             { "timezone.excity.Europe/Lisbon", "Lisboa" },
             { "timezone.excity.Pacific/Gambier", "Gambier" },
@@ -1961,6 +1927,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "America/Santiago", Chile },
             { "timezone.excity.Europe/Zaporozhye", "Zaporizjzja" },
             { "Asia/Baku", Azerbaijan },
+            { "ART", Europe_Eastern },
             { "America/Argentina/Ushuaia", Argentina },
             { "Atlantic/Reykjavik", GMT },
             { "Africa/Brazzaville", Africa_Western },
@@ -1971,17 +1938,8 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Kampala", "Kampala" },
             { "timezone.excity.Pacific/Chatham", "Chatham" },
             { "Africa/Dar_es_Salaam", Africa_Eastern },
-            { "Antarctica/Palmer",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Addis_Ababa", Africa_Eastern },
+            { "AST", Alaska },
             { "Europe/Uzhgorod", Europe_Eastern },
             { "timezone.excity.Asia/Colombo", "Colombo" },
             { "timezone.excity.Pacific/Port_Moresby", "Port Moresby" },
@@ -1999,6 +1957,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Atlantic/South_Georgia", South_Georgia },
             { "Europe/Lisbon", Europe_Western },
             { "Asia/Harbin", China },
+            { "PRT", Atlantic },
             { "Asia/Novokuznetsk", Krasnoyarsk },
             { "timezone.excity.America/Cordoba", "C\u00f3rdoba" },
             { "timezone.excity.America/Cambridge_Bay", "Cambridge Bay" },
@@ -2018,6 +1977,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "timezone.excity.Australia/Sydney", "Sydney" },
             { "timezone.excity.Asia/Qatar", "Qatar" },
             { "timezone.excity.America/Sitka", "Sitka" },
+            { "PST", America_Pacific },
             { "SystemV/EST5", America_Eastern },
             { "timezone.excity.Antarctica/Davis", "Davis" },
             { "America/Santo_Domingo", Atlantic },
@@ -2068,6 +2028,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "America/Tortola", Atlantic },
             { "America/Porto_Velho", Amazon },
             { "America/Scoresbysund", Greenland_Eastern },
+            { "NST", New_Zealand },
             { "timezone.excity.Asia/Samarkand", "Samarkand" },
             { "Africa/Khartoum", Africa_Central },
             { "timezone.excity.Australia/Adelaide", "Adelaide" },
@@ -2115,31 +2076,11 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Asia/Atyrau", Kazakhstan_Western },
             { "Australia/Darwin", Australia_Central },
             { "Asia/Kuala_Lumpur", Malaysia },
-            { "Asia/Famagusta",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Europe/Bratislava", Europe_Central },
             { "timezone.excity.Atlantic/Stanley", "Stanley" },
             { "Pacific/Tongatapu", Tonga },
             { "timezone.excity.Asia/Rangoon", "Yang\u00f4n" },
             { "timezone.excity.Asia/Thimphu", "Thimphu" },
-            { "Europe/Ulyanovsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "timezone.excity.Asia/Dubai", "Dubai" },
             { "Arctic/Longyearbyen", Europe_Central },
             { "timezone.excity.Asia/Kuala_Lumpur", "Kuala Lumpur" },
@@ -2147,16 +2088,6 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Indian/Kerguelen", French_Southern },
             { "timezone.excity.Africa/Ouagadougou", "Ouagadougou" },
             { "timezone.excity.Africa/Gaborone", "Gaborone" },
-            { "Asia/Srednekolymsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "timezone.excity.Indian/Chagos", "Chagos" },
             { "timezone.excity.Asia/Kabul", "Kabul" },
             { "timezone.excity.America/Iqaluit", "Iqaluit" },
